@@ -8,7 +8,7 @@ use 5.008;
 use warnings;
 use strict;
 
-our $VERSION = '5.907'; # TRIAL VERSION from OurPkgVersion
+our $VERSION = '5.908'; # TRIAL VERSION from OurPkgVersion
 
 require Exporter;
 our @ISA    = qw(Exporter);
@@ -60,8 +60,8 @@ HTML::Parse - Deprecated, a wrapper around HTML::TreeBuilder
 =head1 VERSION
 
 B<This is a development release for testing purposes only.>
-This document describes version 5.907 of
-HTML::Parse, released September 13, 2013
+This document describes version 5.908 of
+HTML::Parse, released May 17, 2014
 as part of L<HTML-Tree|HTML::Tree>.
 
 =head1 SYNOPSIS
@@ -175,7 +175,7 @@ Former maintainers:
 =back
 
 You can follow or contribute to HTML-Tree's development at
-L<< http://github.com/madsen/HTML-Tree >>.
+L<< https://github.com/madsen/HTML-Tree >>.
 
 =head1 COPYRIGHT AND LICENSE
 
